@@ -1,17 +1,19 @@
 /*-
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,7 +35,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#include <thunar-vfs/thunar-vfs.h>
+#include <libxfce4util/libxfce4util.h>
 
 #include "tgh-common.h"
 #include "tgh-dialog-common.h"
@@ -73,14 +75,15 @@ static gboolean clone_spawn (GtkWidget *dialog, gchar *repository, gchar *path,
   gchar **argv;
   struct exit_args *args;
 
-  argv = g_new(gchar*, 6);
+  argv = g_new(gchar*, 7);
 
   argv[0] = "git";
-  argv[1] = "clone";
-  argv[2] = "--";
-  argv[3] = repository;
-  argv[4] = path;
-  argv[5] = NULL;
+  argv[1] = "--no-pager";
+  argv[2] = "clone";
+  argv[3] = "--";
+  argv[4] = repository;
+  argv[5] = path;
+  argv[6] = NULL;
 
   if(!g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD | G_SPAWN_SEARCH_PATH, NULL, NULL, pid, NULL, NULL, &fd_err, &error))
   {
