@@ -1,30 +1,30 @@
 /*-
- * Copyright (c) 2006 Peter de Ridder <peter@xfce.org>
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <thunar-vfs/thunar-vfs.h>
+#include <libxfce4util/libxfce4util.h>
 #include <gtk/gtk.h>
 
 #include "tgh-common.h"
+#include "tgh-cell-renderer-graph.h"
 #include "tgh-log-dialog.h"
 
 static void selection_changed (GtkTreeView*, gpointer);
@@ -35,7 +35,10 @@ struct _TghLogDialog
 {
   GtkDialog dialog;
 
+  GList *graph;
+
   GtkWidget *tree_view;
+  GtkWidget *revision_label;
   GtkWidget *text_view;
   GtkWidget *file_view;
   GtkWidget *close;
@@ -84,6 +87,7 @@ enum {
   COLUMN_MESSAGE,
   COLUMN_FULL_MESSAGE,
   COLUMN_FILE_LIST,
+  COLUMN_GRAPH,
   COLUMN_COUNT
 };
 
@@ -98,12 +102,14 @@ static void
 tgh_log_dialog_init (TghLogDialog *dialog)
 {
   GtkWidget *button;
+  GtkWidget *label;
   GtkWidget *tree_view;
   GtkWidget *text_view;
   GtkWidget *file_view;
   GtkWidget *scroll_window;
   GtkWidget *pane;
   GtkWidget *vpane;
+  GtkWidget *box;
   GtkCellRenderer *renderer;
   GtkTreeModel *model;
 
@@ -114,7 +120,16 @@ tgh_log_dialog_init (TghLogDialog *dialog)
 
   dialog->tree_view = tree_view = gtk_tree_view_new ();
 
+  renderer = tgh_cell_renderer_graph_new ();
+  g_object_set (G_OBJECT (renderer), "xalign", 0.5f, NULL);
+  gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
+      -1, "", renderer,
+      "graph-iter", COLUMN_GRAPH,
+      NULL);
+
   renderer = gtk_cell_renderer_text_new ();
+  g_object_set (G_OBJECT (renderer), "width-chars", 9, NULL);
+  g_object_set (G_OBJECT (renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
       -1, _("Revision"),
       renderer, "text",
@@ -132,6 +147,7 @@ tgh_log_dialog_init (TghLogDialog *dialog)
       renderer, "text",
       COLUMN_AUTHOR_DATE, NULL);
 
+#if 0
   renderer = gtk_cell_renderer_text_new ();
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
       -1, _("Commit"),
@@ -143,6 +159,7 @@ tgh_log_dialog_init (TghLogDialog *dialog)
       -1, _("CommitDate"),
       renderer, "text",
       COLUMN_COMMIT_DATE, NULL);
+#endif
 
   renderer = gtk_cell_renderer_text_new ();
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
@@ -150,7 +167,7 @@ tgh_log_dialog_init (TghLogDialog *dialog)
       renderer, "text",
       COLUMN_MESSAGE, NULL);
 
-  model = GTK_TREE_MODEL (gtk_list_store_new (COLUMN_COUNT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER));
+  model = GTK_TREE_MODEL (gtk_list_store_new (COLUMN_COUNT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_POINTER));
 
   gtk_tree_view_set_model (GTK_TREE_VIEW (tree_view), model);
 
@@ -163,20 +180,31 @@ tgh_log_dialog_init (TghLogDialog *dialog)
   gtk_widget_show (tree_view);
   gtk_widget_show (scroll_window);
 
+  vpane = gtk_vpaned_new ();
+
+  box = gtk_vbox_new (FALSE, 0);
+
+  dialog->revision_label = label = gtk_label_new (_("Revision"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+  gtk_label_set_selectable (GTK_LABEL (label), TRUE);
+  gtk_box_pack_start (GTK_BOX (box), label, FALSE, TRUE, 0);
+  gtk_widget_show (label);
+
   scroll_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll_window), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 
-  vpane = gtk_vpaned_new ();
-
   dialog->text_view = text_view = gtk_text_view_new ();
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (text_view), GTK_WRAP_WORD_CHAR);
   gtk_text_view_set_editable (GTK_TEXT_VIEW (text_view), FALSE);
 
   gtk_container_add (GTK_CONTAINER (scroll_window), text_view);
-  gtk_paned_pack1 (GTK_PANED(vpane), scroll_window, TRUE, FALSE);
+  gtk_box_pack_end (GTK_BOX (box), scroll_window, TRUE, TRUE, 0);
   gtk_widget_show (text_view);
   gtk_widget_show (scroll_window);
 
+  gtk_paned_pack1 (GTK_PANED(vpane), box, TRUE, FALSE);
+  gtk_widget_show (box);
+
   scroll_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
@@ -255,19 +283,119 @@ tgh_log_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags flags)
   return GTK_WIDGET(dialog);
 }
 
+static void
+tgh_graph_node_free (TghGraphNode *node)
+{
+  TghGraphNode *next;
+
+  while (node)
+  {
+    g_free (node->name);
+    g_strfreev (node->junction);
+
+    next = node->next;
+    g_free (node);
+    node = next;
+  }
+}
+
+static TghGraphNode*
+tgh_graph_node_add (TghGraphNode *prev)
+{
+  TghGraphNode *node = g_new0 (TghGraphNode, 1);
+  if (prev)
+    prev->next = node;
+  return node;
+}
+
+static TghGraphNode*
+add_n_check_node (TghGraphNode *node_iter, TghGraphNode **node_list, const gchar *name, const gchar *revision, gchar **parents, gboolean *found)
+{
+  TghGraphNode *iter;
+
+  for (iter = *node_list; iter; iter = iter->next)
+  {
+    if (G_UNLIKELY(0 == strcmp (iter->name, name)))
+      return node_iter;
+  }
+
+  node_iter = tgh_graph_node_add (node_iter);
+
+  if (G_UNLIKELY (!*node_list))
+    *node_list = node_iter;
+
+  node_iter->name = g_strdup (name);
+
+  if (G_UNLIKELY (0 == strcmp (revision, name)))
+  {
+    *found = TRUE;
+    node_iter->type = TGH_GRAPH_JUNCTION;
+    node_iter->junction = g_strdupv (parents);
+  }
+
+  return node_iter;
+}
+
 void     
-tgh_log_dialog_add (TghLogDialog *dialog, GSList *files, const gchar *revision, const gchar *author, const gchar *author_date, const gchar *commit, const gchar *commit_date, const gchar *message)
+tgh_log_dialog_add (TghLogDialog *dialog, GSList *files, const gchar *revision, gchar **parents, const gchar *author, const gchar *author_date, const gchar *commit, const gchar *commit_date, const gchar *message)
 {
   GtkTreeModel *model;
   GtkTreeIter iter;
   gchar **lines = NULL;
   gchar **line_iter;
   gchar *first_line = NULL;
+  GList *graph;
+  TghGraphNode *next_node_list;
+  TghGraphNode *next_node_iter;
+  TghGraphNode *node_list = NULL;
+  TghGraphNode *node_iter = NULL;
+  gchar **junction_iter;
+  gboolean found = FALSE;
 
   g_return_if_fail (TGH_IS_LOG_DIALOG (dialog));
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->tree_view));
 
+  graph = dialog->graph;
+
+  if (graph)
+  {
+    next_node_list = graph->data;
+
+    for (next_node_iter = next_node_list; next_node_iter; next_node_iter = next_node_iter->next)
+    {
+      switch (next_node_iter->type)
+      {
+        case TGH_GRAPH_LINE:
+          node_iter = add_n_check_node (node_iter, &node_list, next_node_iter->name, revision, parents, &found);
+          break;
+        case TGH_GRAPH_JUNCTION:
+          if (G_LIKELY (next_node_iter->junction))
+          {
+            for (junction_iter = next_node_iter->junction; *junction_iter; junction_iter++)
+            {
+              node_iter = add_n_check_node (node_iter, &node_list, *junction_iter, revision, parents, &found);
+            }
+          }
+          break;
+      }
+    }
+  }
+
+  if (!found)
+  {
+    node_iter = g_new0 (TghGraphNode, 1);
+    node_iter->next = node_list;
+    node_iter->name = g_strdup (revision);
+    node_iter->type = TGH_GRAPH_JUNCTION;
+    node_iter->junction = g_strdupv (parents);
+    node_list = node_iter;
+  }
+
+  graph = g_list_prepend (graph, node_list);
+
+  dialog->graph = graph;
+
   if(message)
   {
     lines = g_strsplit_set (message, "\r\n", -1);
@@ -293,6 +421,7 @@ tgh_log_dialog_add (TghLogDialog *dialog, GSList *files, const gchar *revision,
       COLUMN_MESSAGE, first_line,
       COLUMN_FULL_MESSAGE, message,
       COLUMN_FILE_LIST, files,
+      COLUMN_GRAPH, graph,
       -1);
 
   g_strfreev (lines);
@@ -313,6 +442,7 @@ selection_changed (GtkTreeView *tree_view, gpointer user_data)
   GtkTreeIter iter;
   GtkTreeSelection *selection;
   GtkTreeModel *model;
+  gchar *revision;
   gchar *message;
   GSList *files;
 
@@ -322,7 +452,11 @@ selection_changed (GtkTreeView *tree_view, gpointer user_data)
 
   if (gtk_tree_selection_get_selected (selection, &model, &iter))
   {
-    gtk_tree_model_get (model, &iter, COLUMN_FULL_MESSAGE, &message, COLUMN_FILE_LIST, &files, -1);
+    gtk_tree_model_get (model, &iter, COLUMN_REVISION, &revision, COLUMN_FULL_MESSAGE, &message, COLUMN_FILE_LIST, &files, -1);
+
+    gtk_label_set_text (GTK_LABEL (dialog->revision_label), revision);
+    g_free (revision);
+
     gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (dialog->text_view)), message?message:"", -1);
     g_free (message);
 
@@ -372,6 +506,10 @@ refresh_clicked (GtkButton *button, gpointer user_data)
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->tree_view));
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
+  g_list_foreach(dialog->graph, (GFunc)tgh_graph_node_free, NULL);
+  g_list_free (dialog->graph);
+  dialog->graph = NULL;
+
   gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (dialog->text_view)), "", -1);
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->file_view));
