@@ -1,30 +1,30 @@
 /*-
- * Copyright (c) 2006 Peter de Ridder <peter@xfce.org>
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <thunar-vfs/thunar-vfs.h>
+#include <libxfce4util/libxfce4util.h>
 #include <gtk/gtk.h>
 
 #include "tgh-common.h"
+#include "tgh-dialog-common.h"
 #include "tgh-stash-dialog.h"
 
 static void selection_changed (GtkTreeView*, gpointer);
@@ -34,7 +34,6 @@ static void apply_clicked (GtkButton*, gpointer);
 static void pop_clicked (GtkButton*, gpointer);
 static void drop_clicked (GtkButton*, gpointer);
 static void clear_clicked (GtkButton*, gpointer);
-static void tgh_make_homogeneous (GtkWidget *, ...) G_GNUC_NULL_TERMINATED;
 
 struct _TghStashDialog
 {
@@ -221,15 +220,8 @@ tgh_stash_dialog_init (TghStashDialog *dialog)
   gtk_widget_show (vpane);
 
   //gtk_button_box_set_layout(GTK_BUTTON_BOX (GTK_DIALOG (dialog)->action_area), GTK_BUTTONBOX_EDGE);
-  gtk_container_remove (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), GTK_DIALOG (dialog)->action_area);
-
-  GTK_DIALOG (dialog)->action_area = box = gtk_hbox_new (FALSE, 0);
-
-  gtk_box_pack_end (GTK_BOX (GTK_DIALOG (dialog)->vbox), box,
-      FALSE, TRUE, 0);
-  gtk_widget_show (box);
-
-  gtk_box_reorder_child (GTK_BOX (GTK_DIALOG (dialog)->vbox), box, 0);
+  tgh_dialog_replace_action_area (GTK_DIALOG (dialog));
+  box = GTK_DIALOG (dialog)->action_area;
 
   //box = gtk_hbox_new (FALSE, 12);
 
@@ -299,38 +291,6 @@ tgh_stash_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags flag
   return GTK_WIDGET(dialog);
 }
 
-static void
-tgh_make_homogeneous (GtkWidget *first, ...)
-{
-  GtkWidget *iter;
-  GtkRequisition request;
-  gint max_width = 0;
-  gint max_height = 0;
-  va_list ap;
-
-  va_start (ap, first);
-  iter = first;
-  while (iter)
-  {
-    gtk_widget_size_request(iter, &request);
-    if (request.width > max_width)
-      max_width = request.width;
-    if (request.height > max_height)
-      max_height = request.height;
-    iter = va_arg (ap, GtkWidget *);
-  }
-  va_end (ap);
-
-  va_start (ap, first);
-  iter = first;
-  while (iter)
-  {
-    gtk_widget_set_size_request (iter, max_width, max_height);
-    iter = va_arg (ap, GtkWidget *);
-  }
-  va_end (ap);
-}
-
 void       
 tgh_stash_dialog_add (TghStashDialog *dialog, const gchar *name, const gchar *branch, const gchar *description)
 {
