@@ -1,17 +1,19 @@
 /*-
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -22,18 +24,20 @@
 #include <stdlib.h>
 #endif
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include <glib.h>
 #include <gtk/gtk.h>
-
-#include <thunar-vfs/thunar-vfs.h>
-
+#include <libxfce4util/libxfce4util.h>
 #include "tgh-common.h"
 #include "tgh-dialog-common.h"
 #include "tgh-status-dialog.h"
 
 #include "tgh-status.h"
 
-static gchar *argv[] = {"git", "status", NULL};
+static gchar *argv[] = {"git", "--no-pager", "status", NULL};
 
 static gboolean status_spawn (TghStatusDialog *dialog, GPid *pid)
 {
@@ -74,16 +78,16 @@ gboolean tgh_status (gchar **files, GPid *pid)
 {
   GtkWidget *dialog;
 
+  if (files)
+    if (chdir(files[0]))
+      return FALSE;
+
   dialog = tgh_status_dialog_new (NULL, NULL, 0);
   g_signal_connect(dialog, "cancel-clicked", tgh_cancel, NULL);
   tgh_dialog_start (GTK_DIALOG (dialog), TRUE);
 
   g_signal_connect(dialog, "refresh-clicked", G_CALLBACK(create_status_child), NULL);
 
-  if (files)
-    if (chdir(files[0]))
-      return FALSE;
-
   return status_spawn(TGH_STATUS_DIALOG(dialog), pid);
 }
 
