@@ -1,17 +1,19 @@
 /*-
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,7 +27,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#include <thunar-vfs/thunar-vfs.h>
+#include <libxfce4util/libxfce4util.h>
 
 #include <apr_lib.h>
 
@@ -157,6 +159,7 @@ gboolean tsh_create_context (svn_client_ctx_t **pctx, apr_pool_t *pool, svn_erro
 	/* Set cancel funvtion */
 	ctx->cancel_func = tsh_check_cancel;
 
+#if CHECK_SVN_VERSION(1,5)
 	/* Create an array to hold the providers */
 	providers = apr_array_make (pool, 12, sizeof (svn_auth_provider_object_t *));
 
@@ -169,6 +172,12 @@ gboolean tsh_create_context (svn_client_ctx_t **pctx, apr_pool_t *pool, svn_erro
 	svn_auth_get_keychain_simple_provider (&provider, pool);
 	APR_ARRAY_PUSH (providers, svn_auth_provider_object_t *) = provider;
 #endif
+#else /* CHECK_SVN_VERSION(1,6)*/
+  /* Create an array to hold the providers */
+  svn_auth_get_platform_specific_client_providers (&providers, cfg, pool);
+#endif
+
+  /* Disk caching auth providers */
 #if CHECK_SVN_VERSION(1,5)
 	svn_auth_get_simple_provider (&provider, pool);
 #else /* CHECK_SVN_VERSION(1,6)*/
@@ -179,6 +188,16 @@ gboolean tsh_create_context (svn_client_ctx_t **pctx, apr_pool_t *pool, svn_erro
 	APR_ARRAY_PUSH (providers, svn_auth_provider_object_t *) = provider;
 
 	/* Cert auth providers */
+#if CHECK_SVN_VERSION(1,5)
+#ifdef G_OS_WIN32
+  svn_auth_get_windows_ssl_server_trust_provider (&provider, pool);
+  APR_ARRAY_PUSH (providers, svn_auth_provider_object_t *) = provider;
+#endif
+#else /* CHECK_SVN_VERSION(1,6)*/
+  svn_auth_get_platform_specific_provider (&provider, "windows", "ssl_server_trust", pool);
+  if (provider)
+    APR_ARRAY_PUSH (providers, svn_auth_provider_object_t *) = provider;
+#endif
 	svn_auth_get_ssl_server_trust_file_provider (&provider, pool);
 	APR_ARRAY_PUSH (providers, svn_auth_provider_object_t *) = provider;
 	svn_auth_get_ssl_client_cert_file_provider (&provider, pool);
