@@ -1,27 +1,26 @@
 /*-
- * Copyright (c) 2006 Peter de Ridder <peter@xfce.org>
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <thunar-vfs/thunar-vfs.h>
+#include <libxfce4util/libxfce4util.h>
 #include <gtk/gtk.h>
 
 #include <subversion-1/svn_client.h>
@@ -43,6 +42,8 @@ struct _TshLogDialog
 	GtkWidget *tree_view;
   GtkWidget *text_view;
   GtkWidget *file_view;
+  GtkWidget *strict_history;
+  GtkWidget *merged_revisions;
 	GtkWidget *close;
 	GtkWidget *cancel;
 	GtkWidget *refresh;
@@ -108,6 +109,9 @@ tsh_log_dialog_init (TshLogDialog *dialog)
 	GtkWidget *scroll_window;
   GtkWidget *pane;
   GtkWidget *vpane;
+  GtkWidget *strict_history;
+  GtkWidget *merged_revisions;
+  GtkWidget *table;
 	GtkCellRenderer *renderer;
 	GtkTreeModel *model;
   gint n_columns;
@@ -205,6 +209,19 @@ tsh_log_dialog_init (TshLogDialog *dialog)
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), pane, TRUE, TRUE, 0);
   gtk_widget_show (pane);
 
+  table = gtk_table_new (3, 2, FALSE);
+
+  dialog->strict_history = strict_history = gtk_check_button_new_with_label (_("Stop On Copy"));
+  gtk_table_attach (GTK_TABLE (table), strict_history, 0, 1, 0, 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+  gtk_widget_show (strict_history);
+
+  dialog->merged_revisions = merged_revisions = gtk_check_button_new_with_label (_("Show Merged Revisions"));
+  gtk_table_attach (GTK_TABLE (table), merged_revisions, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+  gtk_widget_show (merged_revisions);
+
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, FALSE, FALSE, 0);
+  gtk_widget_show (table);
+
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Log"));
 
   gtk_button_box_set_layout(GTK_BUTTON_BOX (GTK_DIALOG (dialog)->action_area), GTK_BUTTONBOX_EDGE);
@@ -338,6 +355,22 @@ tsh_log_dialog_done (TshLogDialog *dialog)
   gtk_widget_show (dialog->refresh);
 }
 
+gboolean
+tsh_log_dialog_get_hide_copied (TshLogDialog *dialog)
+{
+  g_return_val_if_fail (TSH_IS_LOG_DIALOG (dialog), FALSE);
+
+  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->strict_history));
+}
+
+gboolean
+tsh_log_dialog_get_show_merged (TshLogDialog *dialog)
+{
+  g_return_val_if_fail (TSH_IS_LOG_DIALOG (dialog), FALSE);
+
+  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->merged_revisions));
+}
+
 static void
 selection_changed (GtkTreeView *tree_view, gpointer user_data)
 {
